@@ -8,12 +8,30 @@
 #
 # Script to be started in .../cproxy-mp/src
 #
+# Takes one optional argument. "all" to rebuild everything
+# or "clean" to do a make clean everywhere first, and then rebuild
 
 DIRS="yaz yazpp metaproxy"
 
 DIR=`pwd`
 cd ../.. # now in .../proj
 BUILDIT="no"
+if [ "$1" == "all" ]
+then
+  BUILDIT="yes"
+fi
+if [ "$1" == "clean" ]
+then
+  BUILDIT="yes"
+  for D in $DIRS
+  do
+    cd $D
+    echo cleaning $D
+    make clean
+    cd ..
+  done
+fi
+
 
 for D in $DIRS
 do
@@ -63,4 +81,4 @@ echo "======== `pwd`"
 make clean
 git pull
 make && make check && echo "Everything looks fine"
-# need to make clean, to be sure to link with the latest libraries
\ No newline at end of file
+# need to make clean, to be sure to link with the latest libraries
