@@ -281,6 +281,7 @@ mp::Package *make_package(const char *url, int use_full_host,
                           std::string method = "GET",
                           std::string content = "")
 {
+    yaz_log(YLOG_LOG, "--- %s %s  (f=%d) ---", method.c_str(), url, use_full_host);
     mp::Package *pack = new mp::Package;
     Z_GDU *gdu_req = z_get_HTTP_Request_uri(odr, url, 0, use_full_host);
     Z_HTTP_Request *hreq = gdu_req->u.HTTP_Request;
@@ -333,12 +334,14 @@ std::string url_enc( std::string comp )
 // We keep a (global) list of files we have created, so we can delete them
 std::vector<std::string> tempfilelist;
 
-// Make a cf-config file, of the old type
-// can also produce a bad tag, when sesdir is empty
+// Make a cf-config file.
+// Can also produce a bad tag, when sesdir is empty
 void make_cf_config( std::string name,
                      std::string proxyhostname,
                      std::string sesdir,
-                     std::string cfengine )
+                     std::string cfengine,
+                     std::string proxyprotocol
+                   )
 {
     std::ofstream f(name.c_str());
     f << "# cproxy config file\n\n";
@@ -350,30 +353,13 @@ void make_cf_config( std::string name,
     else
       f << "sessiondir: " << sesdir << "\n";
     f << "cfengine: " << cfengine << "\n";
+    if (!proxyprotocol.empty()) {
+      f << "proxyprotocol: " << proxyprotocol << "\n";
+    }
     f.close();
     tempfilelist.push_back(name);
 } // make_cf_config
 
-// Make a cf-config file of the new type, with http(s?)proxyprefix
-void make_new_cf_config( std::string name,
-                     std::string http,
-                     std::string https,
-                     std::string sesdir,
-                     std::string cfengine )
-{
-    std::ofstream f(name.c_str());
-    f << "# cproxy config file\n\n";
-    f << "# Created by the unit test for filter_cproxy\n";
-    f << "# Should have been deleted at the end of the tests\n\n";
-    if(!http.empty())
-        f << "httpproxyprefix: " << http << "\n";
-    if(!https.empty())
-        f << "httpsproxyprefix: " << https << "\n";
-    f << "sessiondir: " << sesdir << "\n";
-    f << "cfengine: " << cfengine << "\n";
-    f.close();
-    tempfilelist.push_back(name);
-} // make_cf_config
 
 void make_session_file( std::string sesdir,
                         std::string sesno,
@@ -478,11 +464,11 @@ void test0(void)
         "</filter>";
 
     // A cf-config file with unknown tags
-    // Bit silly test, since the prefix is actually optional.
     make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/",  // We do not actually require a path prefix
                    "", // empty session directory triggers a bad tag
-                   "localhost:" CFENGINEPORT );  // cf-zserver
+                   "localhost:" CFENGINEPORT,  // cf-zserver
+                   "" ); // no proxyprotocol
     try {
         mp::filter::CProxy *bad_cpx = make_filter( conf );
         YAZ_CHECK (!"Did not throw an exception for a bad tag");
@@ -496,7 +482,8 @@ void test0(void)
     make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "/localhost:9036",  // Illegal url prefix, can not be split into host and path
                    ".", // session directory
-                   "localhost:" CFENGINEPORT );  // cf-zserver
+                   "localhost:" CFENGINEPORT,  // cf-zserver
+                   "https" ); // proxyprotocol
     try {
         mp::filter::CProxy *bad_cpx = make_filter( conf );
         YAZ_CHECK (!"Did not throw an exception for a missing proxy prefix path");
@@ -505,11 +492,12 @@ void test0(void)
         YAZ_CHECK ("got an exception as expected" );
     }
 
-    // A cf-config file with a good proxyprefix, including a port number
+    // A cf-config file with a good proxyprefix and protocol
     make_cf_config("./cf-config.unittest.cfg", // config file to write
-                   "localhost:987/XXX/node102",
+                   "localhost/XXX/node102",
                    ".", // session directory
-                   "" );  // no cf-zserver
+                   "",  // no cf-zserver
+                   "https");
     try {
         mp::filter::CProxy *good_cpx = make_filter( conf );
     }
@@ -517,11 +505,13 @@ void test0(void)
         YAZ_CHECK (!"Exception parsing config file" );
     }
 
-    // A cf-config file with a good proxyprefix
+    // A cf-config file with a good proxyprefix, including a port number
+    // also 'auto' proxyprotocol.
     make_cf_config("./cf-config.unittest.cfg", // config file to write
-                   "localhost/XXX/node102",
+                   "localhost:987/XXX/node102",
                    ".", // session directory
-                   "" );  // no cf-zserver
+                   "",  // no cf-zserver
+                   "auto");
     try {
         mp::filter::CProxy *good_cpx = make_filter( conf );
     }
@@ -538,7 +528,9 @@ void test0(void)
     make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/XXX/2013",  // Illegal url prefix
                    ".", // session directory
-                   "localhost:" CFENGINEPORT );  // cf-zserver
+                   "localhost:" CFENGINEPORT,  // cf-zserver
+                   ""); // no proxyprotocol
+
     try {
         mp::filter::CProxy *bad_cpx = make_filter( conf );
         YAZ_CHECK (!"Did not throw an exception for a bad proxyprefix!");
@@ -546,19 +538,18 @@ void test0(void)
     catch (std::exception & e) {
         YAZ_CHECK ("got an exception as expected" );
     }
-
-    // A new-style cf-config file with conflicting proxy prefixes
-    make_new_cf_config("./cf-config.unittest.cfg", // config file to write
-                  "http://pxy.id.com/XXX",
-                  "https://pxy.id.com/ZZZ",
+    // A cf-config file with a bad proxy protocol (should be http, https, or auto)
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
+                   "localhost:9036/XXX/node102",
                    ".", // session directory
-                   "localhost:" CFENGINEPORT );  // cf-zserver
+                   "localhost:" CFENGINEPORT,  // cf-zserver
+                   "BAD-PROTOCOL");
     try {
         mp::filter::CProxy *bad_cpx = make_filter( conf );
-        YAZ_CHECK (!"Did not throw an exception for conflicting prefixes!");
+        YAZ_CHECK (!"Did not throw an exception for a bad proxyprefix!");
     }
     catch (std::exception & e) {
-        YAZ_CHECK ("got an exception as expected" );
+        YAZ_CHECK ("got an exception as expected: "  );
     }
 
 }
@@ -606,20 +597,12 @@ void test1(void)
         "  </addrequestheader>\n"
         "</filter>\n";
 
-
-
-    //
-    // A new-style cf-config file with conflicting proxy prefixes
-    make_new_cf_config("./cf-config.unittest.cfg", // config file to write
-                  "", //"http://localhost:9036/XXX/node102",
-                  "https://localhost:9036/XXX/node102",
-                   ".", // session directory
-                   "" );  // no cf-zserver for content connectors, in this test
-/*    make_cf_config("./cf-config.unittest.cfg", // config file to write
+    make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/XXX/node102",  // url prefix
                    ".", // session directory
-                   "" );  // no cf-zserver for content connectors
-*/
+                   "",   // no cf-zserver for content connectors
+                   ""); // no proxyprotocol, defaulting to http
+
     mp::filter::CProxy *cpx = make_filter( conf );
     mp::Package *pack;
 
@@ -828,7 +811,7 @@ void test1(void)
                            "Dump dir ./cf.100.dump/ exists already") );
     delete(pack);
 
-    // simple referer header
+    // simple referer header with old-form url
     pack = make_package("http://localhost:9036/"
         "cproxydebug-trace-verbose-keepcontent-nomove/"
         "page.txt",0);
@@ -842,20 +825,67 @@ void test1(void)
     YAZ_CHECK( check_response_header(pack,"X-MK-Component", " ") );
     delete(pack);
 
-    // TODO - Test for referer headers with https:// and /https/
+    // simple referer header with http
+    pack = make_package("http://localhost:9036/"
+        "cproxydebug-trace-verbose-keepcontent-nomove/"
+        "page.txt",0);
+    // Must have the content-bit (8) in debug, or we fake a regular OK response
+    add_request_header(pack, "Referer",
+         "http://localhost:9036/XXX/node102/100/http/ref.host/ref.path");
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                   "http://localhost:9036/XXX/node102/100/http/ref.host/page.txt") );
+    YAZ_CHECK( check_response_header(pack,"X-MK-Component", " ") );
+    delete(pack);
 
-    // simple referer header with just a host name, no trailing slash
+    // simple referer header with https
+    pack = make_package("http://localhost:9036/"
+        "cproxydebug-trace-verbose-keepcontent-nomove/"
+        "page.txt",0);
+    // Must have the content-bit (8) in debug, or we fake a regular OK response
+    add_request_header(pack, "Referer",
+         "http://localhost:9036/XXX/node102/100/https/ref.host/ref.path");
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                   "http://localhost:9036/XXX/node102/100/https/ref.host/page.txt") );
+    YAZ_CHECK( check_response_header(pack,"X-MK-Component", " ") );
+    delete(pack);
+
+    // simple referer header with just a host name, no trailing slash, and no proto
     pack = make_package("http://localhost:9036/cproxydebug-15/page.txt",0);
     // Must have the content-bit (8) in debug, or we fake a regular OK response
     add_request_header(pack, "Referer",
                        "http://localhost:9036/XXX/node102/100/ref.host");
     cpx->process(*pack);
-    
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
                   "http://localhost:9036/XXX/node102/100/ref.host/page.txt") );
     delete(pack);
-    
+
+    // simple referer header with just a host name, no trailing slash, with http proto
+    pack = make_package("http://localhost:9036/cproxydebug-15/page.txt",0);
+    // Must have the content-bit (8) in debug, or we fake a regular OK response
+    add_request_header(pack, "Referer",
+                       "http://localhost:9036/XXX/node102/100/http/ref.host");
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                  "http://localhost:9036/XXX/node102/100/http/ref.host/page.txt") );
+    delete(pack);
+
+    // simple referer header with just a host name, no trailing slash, with https proto
+    pack = make_package("http://localhost:9036/cproxydebug-15/page.txt",0);
+    // Must have the content-bit (8) in debug, or we fake a regular OK response
+    add_request_header(pack, "Referer",
+                       "http://localhost:9036/XXX/node102/100/https/ref.host");
+    cpx->process(*pack);
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                  "http://localhost:9036/XXX/node102/100/https/ref.host/page.txt") );
+    delete(pack);
+
     // Referer header that ends in a sequence of digits, that can be mistaken
     // for a session number
     // Real-life example from CP-3094 SAFARI_BOOKSONLINE
@@ -863,7 +893,6 @@ void test1(void)
     add_request_header(pack, "Referer",
                        "http://localhost:9036/XXX/node102/100/proquestcombo.safaribooksonline.com/book/programming/game-programming/9780321670311");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
                     "http://localhost:9036/XXX/node102/100/proquestcombo.safaribooksonline.com/static/201306-7302-proquestcombo/images/6.0/logo.png") );    
@@ -875,25 +904,23 @@ void test1(void)
     add_request_header(pack, "Referer",
                        "http://localhost:9036/XXX/node102/100/ref.host/");
     cpx->process(*pack);
-    
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
                                      "http://localhost:9036/XXX/node102/100/ref.host/page.txt") );
     
     delete(pack);
     
-    // Referer header with a longer path, and params
+    // Referer header with a longer path, and params, https
     pack = make_package("http://localhost:9036/cproxydebug-15/"
                "path/to/page.txt?param=value",0);
     // Must have the content-bit (8) in debug, or we fake a regular OK response
     add_request_header(pack, "Referer",
-         "http://localhost:9036/XXX/node102/100/"
+         "http://localhost:9036/XXX/node102/100/https/"
          "ref.host/ref.path/ref.to/ref.page.html");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
-          "http://localhost:9036/XXX/node102/100/"
+          "http://localhost:9036/XXX/node102/100/https/"
           "ref.host/path/to/page.txt?param=value") );
     delete(pack);
 
@@ -905,7 +932,6 @@ void test1(void)
          "http://localhost:9036/XXX/node102/100/"
          "ref.host/ref.path/ref.to/ref.page.html");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
           "http://localhost:9036/XXX/node102/100/"
@@ -919,10 +945,9 @@ void test1(void)
     add_request_header(pack, "Cookie",
                 "name1=value1;cproxysession=https/fakehost.com/100 ; name3=value3");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
-          "https://localhost:9036/XXX/node102/100/"
+          "http://localhost:9036/XXX/node102/100/"
           "https/fakehost.com/path/to/page.txt") );
     delete(pack);
 
@@ -933,10 +958,9 @@ void test1(void)
     add_request_header(pack, "Cookie",
                 "name1=value1;cproxysession=https/fakehost.com:888/100 ; name3=value3");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
-          "https://localhost:9036/XXX/node102/100/"
+          "http://localhost:9036/XXX/node102/100/"
           "https/fakehost.com:888/path/to/page.txt") );
     delete(pack);
 
@@ -962,7 +986,6 @@ void test1(void)
          "http://localhost:9036/XXX/node102/100/"
          "ref.host/ref.path/ref.to/ref.page.html");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 302) );
     YAZ_CHECK( check_response_header(pack, "Location",
           "http://localhost:9036/XXX/node102/100/"
@@ -1014,7 +1037,6 @@ void test1(void)
                         "101/www.indexdata.com/staff/",0);
     add_request_header(pack, "Cookie","one=first;four=fourth");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 200) );
     YAZ_CHECK( check_request_header(pack, "Cookie",
                             "one=first;four=fourth;mixedcase=true;two=TWO") );
@@ -1043,7 +1065,6 @@ void test1(void)
                         "102/www.indexdata.com/staff/",0);
     add_request_header(pack, "Cookie","one=first;four=fourth");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 200) );
     YAZ_CHECK( check_response_content(pack, "Got session '102'" ) );
     YAZ_CHECK( check_response_content(pack, "New cookie line name='newcookie' value='newvalue'" ) );
@@ -1052,6 +1073,7 @@ void test1(void)
     YAZ_CHECK( check_request_header(pack, "Cookie", // no newcookie4, wrong path
             "one=first;four=fourth;newcookie3=v3;newcookie2=v2;newcookie=newvalue") );
     delete(pack);   
+
     // Second request, to indexdata.dk. Will match basicauthwith, so expect auth
     pack = make_package("http://localhost:9036/XXX/cproxydebug-verbose-nomove-dump/node102/"
                         "102/www.indexdata.dk/staff/",0);
@@ -1067,6 +1089,7 @@ void test1(void)
     YAZ_CHECK( check_response_code(pack, 200) );
     YAZ_CHECK( check_request_header(pack, "Cookie", "infoweb=dot;newcookie=newvalue") );
     delete(pack);
+
     // CPXY-146: Request to infoweb.newsbank.com (no leading dot). Should also get the cookie. 
     pack = make_package("http://localhost:9036/XXX/cproxydebug-verbose-nomove-dump/node102/"
                         "102/infoweb.newsbank.com/staff/",0);
@@ -1098,7 +1121,8 @@ void test1(void)
     make_cf_config("./cf-config.unittest.cfg", // config file to write
                    "localhost:9036/XXX/node102",  // url prefix
                    ".", // session directory
-                   "localhost:" CFENGINEPORT );  // cf-zserver
+                   "localhost:" CFENGINEPORT,  // cf-zserver
+                   ""); // no proxyprotocol
     delete(cpx);
     cpx = make_filter( conf );   // read the new config with a cf-zserver
     make_param_file(".", "103",
@@ -1124,7 +1148,6 @@ void test1(void)
                     "testrealm",
                     "cfusername/cfpassword"
                    );
-
     pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-7/node102/"
                         "103/www.indexdata.com/staff/");
     YAZ_CHECK( check_response_code(pack, 400 ) );
@@ -1162,7 +1185,6 @@ void test1(void)
                     "user",
                     "1.2.3.4:80",
                     "" );
-
     pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-7/node102/"
                         "104/www.indexdata.com/staff/");
     YAZ_CHECK( check_response_code(pack, 400 ) );
@@ -1187,14 +1209,12 @@ void test1(void)
                     "testrealm",
                     "cfusername/cfpassword"
                    );
-
     pack = process_url(cpx, "http://localhost:9036/XXX/cproxydebug-7/node102/"
                         "105/www.indexdata.com/staff/");
     YAZ_CHECK( check_response_code(pack, 200 ) );
     YAZ_CHECK( check_response_content(pack, "Faking a null session") );
     YAZ_CHECK( check_request_header(pack, "X-Metaproxy-Proxy", "1.2.3.4:80") );
     YAZ_CHECK( check_request_header(pack, "Authorization", "Basic dXNlcjpwYXNzd2Q=") );
-
     delete(pack);
 
 
@@ -1213,15 +1233,12 @@ void test1(void)
                         "103/omit1.com/staff/",0);
     add_request_header(pack, "Cookie","one=first;");
     cpx->process(*pack);
-
     YAZ_CHECK( check_response_code(pack, 200) );
     YAZ_CHECK( check_response_content(pack, "Got session '103'" ) );
-
     // Cookie should be omitted
     YAZ_CHECK( !check_request_header(pack, "Cookie",  "one=first") );
     // Should have auth header, no matter what domain
     YAZ_CHECK( check_request_header(pack, "Authorization", "Basic c29tZXVzZXI6") );
-    
     delete(pack);
 
     pack = make_package("http://localhost:9036/XXX/cproxydebug-verbose-nomove-dump/node102/"
@@ -1273,7 +1290,6 @@ void test1(void)
 //  - filter_file to serve static file(s)
 //  - Build static test files for filter_file to return
 //
-// TODO - Various https tests
 void test2 (void)
 {
     mp::Package *pack;
@@ -1281,7 +1297,8 @@ void test2 (void)
     make_cf_config("./cf-config.unittest2.cfg", // config file to write
             "localhost:9036/YYY/ZZZ",  // url prefix
             ".", // session directory
-            "" );  // cf-zserver for content connectors, "localhost:9001"
+            "" ,  // cf-zserver for content connectors, "localhost:9001"
+             "https");
 
 // Comment out the following not to log the packets in every between
 #define LOG_ALL 1
@@ -1359,9 +1376,6 @@ void test2 (void)
                 // Note that the rewrite above always makes requests with
                 // absolute paths, so we need an area with such. I guess it
                 // should not do that.
-                // The whole configuration of the rewrite will be changed soon,
-                // when the new model gets implemented, so I leave this as is
-                // for now. TODO
                 "<filter type='http_file'>\n"
                     "<mimetypes>/etc/mime.types</mimetypes>\n"
                     "<area>\n"
@@ -1554,7 +1568,7 @@ void test2 (void)
     delete(pack);
 
     // Same as above, but without any debug info
-    pack = make_package("http://localhost:9036/"
+    pack = make_package("https://localhost:9036/"
             "YYY/ZZZ/200/"
             "dummyhost.com/testfile/file1.html",1);
     pack->router(router).move();
@@ -1691,9 +1705,47 @@ void test2 (void)
     YAZ_CHECK( check_response_code(pack, 200) );
     delete(pack);
 
-    
+
+    // Referer trick
+    pack = make_package("https://localhost:9036/"
+        // "cproxydebug-trace-verbose-keepcontent-nomove/"  // need the keepcontent
+        "testfile/file1.html",0);
+    add_request_header(pack, "Referer",
+         "http://localhost:9036/YYY/ZZZ/200/https/dummyhost.com/testfile/index.html");
+    pack->router(router).move();
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                   "http://localhost:9036/YYY/ZZZ/200/https/dummyhost.com/testfile/file1.html") );
+    delete(pack);
+
+    // No referer, but a session cookie
+    pack = make_package("https://localhost:9036/"
+        "cproxydebug-trace-verbose-keepcontent-nomove/"  // need the keepcontent
+        "testfile/file1.html",0);
+    add_request_header(pack, "Cookie",
+                "name1=value1;cproxysession=https/dummyhost.com/200 ; name3=value3");
+    pack->router(router).move();
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                   "https://localhost:9036/YYY/ZZZ/200/https/dummyhost.com/testfile/file1.html") );
+    delete(pack);
+
+    // No referer, but a old-form session cookie without proto
+    pack = make_package("https://localhost:9036/"
+        "cproxydebug-trace-verbose-keepcontent-nomove/"  // need the keepcontent
+        "testfile/file1.html",0);
+    add_request_header(pack, "Cookie",
+                "name1=value1;cproxysession=dummyhost.com/200 ; name3=value3");
+    pack->router(router).move();
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack, "Location",
+                   "https://localhost:9036/YYY/ZZZ/200/http/dummyhost.com/testfile/file1.html") );
+    // Note that here we expect a http link.
+    delete(pack);
+
+
     // Page not found
-    pack = make_package("http://localhost:9036/"
+    pack = make_package("https://localhost:9036/"
         "cproxydebug-verbose/"
         "YYY/ZZZ/200/"
         "dummyhost.com/testfile/nosuchfile.html",1);
@@ -1701,12 +1753,11 @@ void test2 (void)
     YAZ_CHECK( check_response_code(pack, 404) );
     YAZ_CHECK( check_response_content(pack, "<TITLE>Metaproxy" ) );
     YAZ_CHECK( check_response_content(pack, "Error: 404" ) );
-    // At the moment the rewrite blindly replaces everything
     YAZ_CHECK( check_response_content(pack, "http://www.w3.org/TR/html4/strict.dtd" ) );
     delete(pack);
     
     // Page not found, without debug info
-    pack = make_package("http://localhost:9036/"
+    pack = make_package("https://localhost:9036/"
         "YYY/ZZZ/200/"
         "dummyhost.com/testfile/nosuchfile.html",1);
     pack->router(router).move();
@@ -1719,7 +1770,7 @@ void test2 (void)
     // CPXY-81. Should process it directly, and not redirect.
     // Also, makes an entry in the _cookietrace, which we analyze later
     std::string contentparams = url_enc("foo=bar") + "&";
-    pack = make_package("http://localhost:9036/"
+    pack = make_package("https://localhost:9036/"
                "cproxydebug-keepcontent-nomove-dump-verbose/"
                "testfile/file1.html",
                1,"POST",contentparams);
@@ -1783,7 +1834,7 @@ void test2 (void)
     YAZ_CHECK( check_any_response_header(pack,"Link",
             "<https://localhost:9036/YYY/ZZZ/200/sub.dummydomain.com/host/relative/>;") );
       // The Link header needs a special regexp, as it has a funny format, with
-      // the URL inside angle brackets. Need to write that. TODO!
+      // the URL inside angle brackets.
     YAZ_CHECK( check_response_header(pack,"X-Do-Not-Look",
                                     "http://do.not.look.com/") );
     // Check the cookie rewriting
@@ -1873,7 +1924,7 @@ void test2 (void)
     // Since it set some cookies last time, those cookies are expected to 
     // be in the request. They are not, and the cookie analysis (below) is 
     // supposed to notice what is missing.
-    pack = make_package("http://localhost:9036/"
+    pack = make_package("https://localhost:9036/"
         "cproxydebug-verbose-dump-keepcontent/"
         "YYY/ZZZ/200/"
         "sub.dummydomain.com/rawtestfile/rawfile.html?second=time",0);
@@ -1948,7 +1999,7 @@ void test2 (void)
     make_html_file( "./movedfile2", movedpage2 );
 
     pack = make_package("http://localhost:9036/"
-          //  "cproxydebug-verbose-dump/"
+            //"cproxydebug-verbose-dump-keepcontent/"
             "YYY/ZZZ/200/"
             "dummyhost.com/rawtestfile/movedfile2",0);
     pack->router(router).move();
@@ -1964,16 +2015,16 @@ void test2 (void)
         "HTTP/1.1 302 Moved\r\n"
         "Location: https://secure.com/login.html\r\n"
         "\r\n";
-     
     make_html_file( "./movedfile3", movedpage3 );
-
     pack = make_package("http://localhost:9036/"
-    "cproxydebug-verbose/"
+     "cproxydebug-verbose-dump-keepcontent/"
     "YYY/ZZZ/200/"
     "dummyhost.com/rawtestfile/movedfile3",0);
     pack->router(router).move();
-    //YAZ_CHECK( check_response_code(pack, 400) );
-    // TODO - Now we can redirect to https, make proper tests
+    YAZ_CHECK( check_response_code(pack, 302) );
+    YAZ_CHECK( check_response_header(pack,"Location",
+                   "https://localhost:9036/YYY/ZZZ/200/https/secure.com/login.html") );
+
     delete(pack);
 
      
