@@ -59,7 +59,7 @@ CfSession 17
 #Password secretpassword
 #Proxyip 1.2.3.4
 Cookie www.indexdata.com; one=ONE
-Custom-Pattern Index Data Custom-Replacement [[INDEX DATA]] Custom-Options i Custom-Content-Type html
+Custom-Replacement Index\sData i html  [[Index Data]]
 END
 echo "Created a simple dummy session 17"
 
