@@ -64,7 +64,7 @@ echo "Created a simple dummy session 17 in $SESDIR"
 echo "You can check it with one of these:"
 echo "  curl http://localhost:8999/XXX/node102/17/www.lsd.dk"
 echo "  curl http://localhost:8999/XXX/node102/17/http/www.lsd.dk"
-echo "  curl http://localhost:8999/XXX/node102/cproxydebug-verbose/17/http/www.lsd.dk"
+echo "  curl -k https://localhost:8999/XXX/node102/cproxydebug-verbose/17/https/www.lsd.dk"
 echo "  curl -k https://localhost:8998/XXX/node102/17/https/www.indexdata.com"
 echo "  curl -k https://localhost:8998/XXX/node102/17/http/localhost:8999/testdata/index.html"
 
